Contributors to pylxd
~~~~~~~~~~~~~~~~~~~~~


These are the contributors to pylxd according to the Github repository.

 ===============  ==================================
 GHsername        Name
 ===============  ==================================
 rockstar         Paul Hummer
 zulcss           Chuck Short
 saviq            Michał Sawicz
 javacruft        James Page (Canonical)
 pcdummy          Rene Jochum
 jpic             ???
 hsoft            Virgil Dupras
 mgwilliams       Matthew Williams
 tych0            Tycho Andersen (Canonical)
 aarnaud          Anthony Arnaud
 moreati          Alex Willmer
 uglide           Igor Malinovskiy
 Itxaka           ???
 ivuk             Igor Vuk
 reversecipher    ???
 stgraber         Stéphane Graber (Canonical)
 toshism          Tosh Lyons
 om26er           Omer Akram
 sergiusens       Sergio Schvezov
 datashaman       ???
 rooty0           ???
 jimmymccrory     Jimmy McCrory
 Synforge         Paul Oyston
 overquota        ???
 chrismacnaughton Chris MacNaughton
 ppkt             Karol Werner
 mrtc0            Kohei Morita
 gabrik           Gabriele Baldoni
 felix-engelmann  Felix Engelmann
 weichweich       ???
 anneborcherding  Anne Borcherding
 cpg1111          Christian Grabowski (Canonical)
 fliiiix          Felix
 simondeziel      Simon Déziel (Canonical)
 sparkiegeek      Adam Collard (Canonical)
 ===============  ==================================

